# Building my own mini-Pytorch wrapper

I want to learn deeply about everything hence this reimplementation

Here is the overview of the process:

1. Basics


---

## The Progress is here

* [ ] Basics

---
## Progress Description
Basic Setup for making it to full fledge library is done. 
I am using Makefile for building the systems, for now the docs and testiing is not done. I will add those things later on. 

### soon
